import React, { useEffect, useState } from 'react'
import Button from '@mui/material/Button' // Updated import for MUI v5
import { Link, useParams } from 'react-router-dom'
import Swal from 'sweetalert2' // Import SweetAlert2
import axios from 'axios'

import Axios from '../../../axios'
import { isAutheticated } from '../../../auth'

const ViewProductManual = () => {
  const [title, setTitle] = useState('')
  const [image, setImage] = useState('')
  const token = isAutheticated()
  const { id } = useParams()

  const getproductmanual = async () => {
    try {
      const res = await Axios.get(`/api/productmanual/getone/${id}`, {
        headers: { Authorization: `Bearer ${token}` },
      })
      setTitle(res?.data?.productManual?.title)
      setImage(res?.data?.productManual?.product_manual)
    } catch (err) {
      console.error(err)
      // SweetAlert2 configuration
      Swal.fire({
        title: 'Error',
        text: 'Unable to fetch the product manual',
        icon: 'error',
        confirmButtonText: 'Retry',
        showCancelButton: true,
        confirmButtonColor: '#d33',
        cancelButtonColor: '#3085d6',
        cancelButtonText: 'Cancel',
      })
    }
  }

  useEffect(() => {
    getproductmanual()
  }, [])

  return (
    <div className="container">
      <div className="row">
        <div className="col-12">
          <div className="page-title-box d-flex align-items-center justify-content-between">
            <div style={{ fontSize: '22px' }} className="fw-bold">
              View Product Manual
            </div>
            <div style={{ display: 'flex', gap: '1rem' }}>
              <h4 className="mb-0"></h4>
            </div>
            <div className="page-title-right">
              <Link to="/product-manual">
                <Button
                  variant="contained"
                  color="secondary"
                  sx={{
                    fontWeight: 'bold',
                    mb: 1,
                    textTransform: 'capitalize',
                  }}
                >
                  Back
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </div>
      <div className="row">
        <div className="col-lg-12 col-md-12 col-sm-12 my-1">
          <div className="card h-100">
            <div className="card-body px-5">
              <h4
                className="card-title"
                style={{
                  fontWeight: 'bold',
                  fontSize: '3rem',
                  marginBottom: '1rem',
                  textTransform: 'capitalize',
                }}
              >
                {title}
              </h4>
              <div className="mb-3">
                {image &&
                  (image.url.endsWith('.pdf') ? (
                    <iframe
                      src={image.url}
                      title="Product Manual"
                      style={{ width: '100%', height: '80vh', border: 'none' }}
                    />
                  ) : (
                    <img src={image.url} alt="blog" style={{ width: '100%', height: '50vh' }} />
                  ))}
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  )
}

export default ViewProductManual
